"""Enumeration of equity compensation types (there are some things around the
margins like RSAs that don\'t currently fit under the EquityCompensation
umbrella but might arguably fall under this. If you want to create an RSA,
create a stock issuance with vesting - you can link it to a plan as well, if you
want).
**The enums stand for:**
1. OPTION_ISO (qualified)
2. OPTION_NSO (non-qualified)
3. OPTION (not NSO or ISO)
4. RSU (restricted share units)
5. CSAR(cash-settled stock appreciation rights)
6. SSAR(stock-settled stock appreciation rights)"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-
# OCF/tree/v1.1.0/schema/enums/CompensationType.schema.json

from enum import Enum


class CompensationType(Enum):
    """Enumeration of equity compensation types (there are some things around the
    margins like RSAs that don\'t currently fit under the EquityCompensation
    umbrella but might arguably fall under this. If you want to create an RSA,
    create a stock issuance with vesting - you can link it to a plan as well, if you
    want).
    **The enums stand for:**
    1. OPTION_ISO (qualified)
    2. OPTION_NSO (non-qualified)
    3. OPTION (not NSO or ISO)
    4. RSU (restricted share units)
    5. CSAR(cash-settled stock appreciation rights)
    6. SSAR(stock-settled stock appreciation rights)
    """

    ENUM_OPTION_NSO = "OPTION_NSO"
    ENUM_OPTION_ISO = "OPTION_ISO"
    ENUM_OPTION = "OPTION"
    ENUM_RSU = "RSU"
    ENUM_CSAR = "CSAR"
    ENUM_SSAR = "SSAR"
