"""Object describing the issuer of the cap table (the company whose cap table this
is)"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-
# OCF/tree/v1.1.0/schema/objects/Issuer.schema.json

from pydantic import Field
from pyocf.primitives.objects.object import Object
from pyocf.types.address import Address
from pyocf.types.countrycode import CountryCode
from pyocf.types.countrysubdivisioncode import CountrySubdivisionCode
from pyocf.types.date import Date
from pyocf.types.email import Email
from pyocf.types.phone import Phone
from pyocf.types.taxid import TaxID
from typing import Annotated
from typing import Literal
from typing import Optional


class Issuer(Object):
    """Object describing the issuer of the cap table (the company whose cap table this
    is)
    """

    object_type: Annotated[Literal["ISSUER"], Field(description="")] = "ISSUER"
    legal_name: Annotated[str, Field(description="Legal name of the issuer")]
    dba: Optional[Annotated[str, Field(description="Doing Business As name")]] = None
    formation_date: Annotated[Date, Field(description="Date of formation")]
    country_of_formation: Annotated[
        CountryCode,
        Field(
            description="The country where the issuer company was legally formed (ISO 3166-1 alpha-2)"
        ),
    ]
    country_subdivision_of_formation: Optional[
        Annotated[
            CountrySubdivisionCode,
            Field(
                description="The state, province, or subdivision where the issuer company was legally formed"
            ),
        ]
    ] = None
    tax_ids: Optional[
        Annotated[list[TaxID], Field(description="The tax ids for this issuer company")]
    ] = None
    email: Optional[
        Annotated[
            Email,
            Field(description="A work email that the issuer company can be reached at"),
        ]
    ] = None
    phone: Optional[
        Annotated[
            Phone,
            Field(
                description="A phone number that the issuer company can be reached at"
            ),
        ]
    ] = None
    address: Optional[
        Annotated[
            Address,
            Field(description="The headquarters address of the issuing company"),
        ]
    ] = None
    id: Annotated[str, Field(description="Identifier for the object")]
    comments: Optional[
        Annotated[
            list[str],
            Field(
                description="Unstructured text comments related to and stored for the object"
            ),
        ]
    ] = None
