"""Object describing a stakeholder"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-
# OCF/tree/v1.1.0/schema/objects/Stakeholder.schema.json

from pydantic import Field
from pyocf.enums.stakeholderrelationshiptype import StakeholderRelationshipType
from pyocf.enums.stakeholdertype import StakeholderType
from pyocf.primitives.objects.object import Object
from pyocf.types.address import Address
from pyocf.types.contactinfo import ContactInfo
from pyocf.types.contactinfowithoutname import ContactInfoWithoutName
from pyocf.types.name import Name
from pyocf.types.taxid import TaxID
from typing import Annotated
from typing import Literal
from typing import Optional


class Stakeholder(Object):
    """Object describing a stakeholder"""

    object_type: Annotated[Literal["STAKEHOLDER"], Field(description="")] = (
        "STAKEHOLDER"
    )
    name: Annotated[Name, Field(description="Name for the stakeholder")]
    stakeholder_type: Annotated[
        StakeholderType, Field(description="Distinguish individuals from institutions")
    ]
    issuer_assigned_id: Optional[
        Annotated[
            str,
            Field(
                description="This might be any sort of id assigned to the stakeholder by the issuer, such as"
                "an internal company ID for an employee stakeholder"
            ),
        ]
    ] = None
    current_relationship: Optional[
        Annotated[
            StakeholderRelationshipType,
            Field(
                description="What is the current relationship of the stakeholder to the issuer?"
            ),
        ]
    ] = None
    primary_contact: Optional[
        Annotated[
            ContactInfo,
            Field(
                description="The primary contact info for an institutional stakeholder"
            ),
        ]
    ] = None
    contact_info: Optional[
        Annotated[
            ContactInfoWithoutName,
            Field(description="The contact info for an individual stakeholder"),
        ]
    ] = None
    addresses: Optional[
        Annotated[list[Address], Field(description="Addresses for the stakeholder")]
    ] = None
    tax_ids: Optional[
        Annotated[list[TaxID], Field(description="The tax ids for this stakeholder")]
    ] = None
    id: Annotated[str, Field(description="Identifier for the object")]
    comments: Optional[
        Annotated[
            list[str],
            Field(
                description="Unstructured text comments related to and stored for the object"
            ),
        ]
    ] = None
