"""Object describing convertible instrument issuance transaction by the issuer and
held by a stakeholder"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-OCF/t
# ree/v1.1.0/schema/objects/transactions/issuance/ConvertibleIssuance.schema.json

from pydantic import Field
from pyocf.enums.convertibletype import ConvertibleType
from pyocf.primitives.objects.object import Object
from pyocf.primitives.objects.transactions.issuance.issuance import Issuance
from pyocf.primitives.objects.transactions.securitytransaction import (
    SecurityTransaction,
)
from pyocf.primitives.objects.transactions.transaction import Transaction
from pyocf.types.conversion_triggers.automaticconversiononconditiontrigger import (
    AutomaticConversionOnConditionTrigger,
)
from pyocf.types.conversion_triggers.automaticconversionondatetrigger import (
    AutomaticConversionOnDateTrigger,
)
from pyocf.types.conversion_triggers.electiveconversionatwilltrigger import (
    ElectiveConversionAtWillTrigger,
)
from pyocf.types.conversion_triggers.electiveconversionindaterangetrigger import (
    ElectiveConversionInDateRangeTrigger,
)
from pyocf.types.conversion_triggers.electiveconversiononconditiontrigger import (
    ElectiveConversionOnConditionTrigger,
)
from pyocf.types.conversion_triggers.unspecifiedconversiontrigger import (
    UnspecifiedConversionTrigger,
)
from pyocf.types.date import Date
from pyocf.types.monetary import Monetary
from pyocf.types.numeric import Numeric
from pyocf.types.securityexemption import SecurityExemption
from typing import Annotated
from typing import Literal
from typing import Optional
from typing import Union


class ConvertibleIssuance(Object, Transaction, SecurityTransaction, Issuance):
    """Object describing convertible instrument issuance transaction by the issuer and
    held by a stakeholder
    """

    object_type: Annotated[
        Literal["TX_CONVERTIBLE_ISSUANCE"], Field(description="")
    ] = "TX_CONVERTIBLE_ISSUANCE"
    investment_amount: Annotated[
        Monetary,
        Field(
            description="Amount invested and outstanding on date of issuance of this convertible"
        ),
    ]
    convertible_type: Annotated[
        ConvertibleType,
        Field(
            description="What kind of convertible instrument is this (of the supported, enumerated types)"
        ),
    ]
    conversion_triggers: Annotated[
        list[
            Annotated[
                Union[
                    AutomaticConversionOnConditionTrigger,
                    AutomaticConversionOnDateTrigger,
                    ElectiveConversionAtWillTrigger,
                    ElectiveConversionInDateRangeTrigger,
                    ElectiveConversionOnConditionTrigger,
                    UnspecifiedConversionTrigger,
                ],
                Field(discriminator="type"),
            ]
        ],
        Field(
            description="In event the convertible can convert due to trigger events (e.g. Maturity, Next"
            "Qualified Financing, Change of Control, at Election of Holder), what are the"
            "terms?"
        ),
    ]
    pro_rata: Optional[
        Annotated[
            Numeric,
            Field(
                description="What pro-rata (if any) is the holder entitled to buy at the next round?"
            ),
        ]
    ] = None
    seniority: Annotated[
        int,
        Field(
            description="If different convertible instruments have seniorty over one another, use this"
            "value to build a seniority stack, with 1 being highest seniority and equal"
            "seniority values assumed to be equal priority"
        ),
    ]
    id: Annotated[str, Field(description="Identifier for the object")]
    comments: Optional[
        Annotated[
            list[str],
            Field(
                description="Unstructured text comments related to and stored for the object"
            ),
        ]
    ] = None
    security_id: Annotated[
        str,
        Field(
            description="Identifier for the security (stock, plan security, warrant, or convertible) by"
            "which it can be referenced by other transaction objects. Note that while this"
            "identifier is created with an issuance object, it should be different than the"
            "issuance object's `id` field which identifies the issuance transaction object"
            "itself. All future transactions on the security (e.g. acceptance, transfer,"
            "cancel, etc.) must reference this `security_id` to qualify which security the"
            "transaction applies to."
        ),
    ]
    date: Annotated[Date, Field(description="Date on which the transaction occurred")]
    custom_id: Annotated[
        str, Field(description="A custom ID for this security (e.g. CN-1.)")
    ]
    stakeholder_id: Annotated[
        str,
        Field(
            description="Identifier for the stakeholder that holds legal title to this security"
        ),
    ]
    board_approval_date: Optional[
        Annotated[Date, Field(description="Date of board approval for the security")]
    ] = None
    consideration_text: Optional[
        Annotated[
            str,
            Field(
                description="Unstructured text description of consideration provided in exchange for security"
                "issuance"
            ),
        ]
    ] = None
    security_law_exemptions: Annotated[
        list[SecurityExemption],
        Field(
            description="List of security law exemptions (and applicable jurisdictions) for this security"
        ),
    ]
