"""Object describing securities issuance transaction by the issuer and held by a
stakeholder as a form of compensation (as noted elsewhere, RSAs are not included
here intentionally and should be modelled using Stock Issuances)."""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-OCF/t
# ree/v1.1.0/schema/objects/transactions/issuance/EquityCompensationIssuance.schem
# a.json

from pydantic import Field
from pyocf.enums.compensationtype import CompensationType
from pyocf.enums.optiontype import OptionType
from pyocf.primitives.objects.object import Object
from pyocf.primitives.objects.transactions.issuance.issuance import Issuance
from pyocf.primitives.objects.transactions.securitytransaction import (
    SecurityTransaction,
)
from pyocf.primitives.objects.transactions.transaction import Transaction
from pyocf.types.date import Date
from pyocf.types.monetary import Monetary
from pyocf.types.numeric import Numeric
from pyocf.types.securityexemption import SecurityExemption
from pyocf.types.terminationwindow import TerminationWindow
from typing import Annotated
from typing import Literal
from typing import Optional
from typing import Union


class EquityCompensationIssuance(Object, Transaction, SecurityTransaction, Issuance):
    """Object describing securities issuance transaction by the issuer and held by a
    stakeholder as a form of compensation (as noted elsewhere, RSAs are not included
    here intentionally and should be modelled using Stock Issuances).
    """

    object_type: Annotated[
        Literal["TX_EQUITY_COMPENSATION_ISSUANCE"],
        Field(
            description="This is done to avoid a breaking change as we work towards a bigger restructure"
            "of the equity types in v2.0.0. `TX_PLAN_SECURITY_ISSUANCE` will be deprecated in"
            "v2.0.0"
        ),
    ] = "TX_EQUITY_COMPENSATION_ISSUANCE"
    stock_plan_id: Optional[
        Annotated[
            str,
            Field(
                description="If the equity compensation was issued from a plan (don't forget, plan-less"
                "options are a thing), what is the plan id."
            ),
        ]
    ] = None
    stock_class_id: Optional[
        Annotated[
            str,
            Field(
                description="If the equity compensation was NOT issued from a plan (don't forget, plan-less"
                "options are a thing), we need to know what underlying stock class it converts"
                "to."
            ),
        ]
    ] = None
    compensation_type: Annotated[
        CompensationType,
        Field(description="If the plan security is compensation, what kind?"),
    ]
    option_grant_type: Optional[
        Annotated[
            OptionType,
            Field(description="If the plan security is an option, what kind?"),
        ]
    ] = None
    quantity: Annotated[
        Numeric, Field(description="How many shares are subject to this plan security?")
    ]
    exercise_price: Optional[
        Annotated[
            Monetary,
            Field(
                description="If this is an option, what is the exercise price of the option?"
            ),
        ]
    ] = None
    base_price: Optional[
        Annotated[
            Monetary,
            Field(
                description="If this is a stock appreciation right, what is the base price used to calculate"
                "the appreciation of the SAR?"
            ),
        ]
    ] = None
    vesting_terms_id: Optional[
        Annotated[
            str,
            Field(
                description="Identifier of the VestingTerms to which this security is subject.  If not"
                "present, security is fully vested on issuance."
            ),
        ]
    ] = None
    expiration_date: Union[None, Date]
    termination_exercise_windows: Annotated[
        list[TerminationWindow],
        Field(
            description="Exercise periods applicable to plan security after a termination for a given,"
            "enumerated reason"
        ),
    ]
    id: Annotated[str, Field(description="Identifier for the object")]
    comments: Optional[
        Annotated[
            list[str],
            Field(
                description="Unstructured text comments related to and stored for the object"
            ),
        ]
    ] = None
    security_id: Annotated[
        str,
        Field(
            description="Identifier for the security (stock, plan security, warrant, or convertible) by"
            "which it can be referenced by other transaction objects. Note that while this"
            "identifier is created with an issuance object, it should be different than the"
            "issuance object's `id` field which identifies the issuance transaction object"
            "itself. All future transactions on the security (e.g. acceptance, transfer,"
            "cancel, etc.) must reference this `security_id` to qualify which security the"
            "transaction applies to."
        ),
    ]
    date: Annotated[Date, Field(description="Date on which the transaction occurred")]
    custom_id: Annotated[
        str, Field(description="A custom ID for this security (e.g. CN-1.)")
    ]
    stakeholder_id: Annotated[
        str,
        Field(
            description="Identifier for the stakeholder that holds legal title to this security"
        ),
    ]
    board_approval_date: Optional[
        Annotated[Date, Field(description="Date of board approval for the security")]
    ] = None
    consideration_text: Optional[
        Annotated[
            str,
            Field(
                description="Unstructured text description of consideration provided in exchange for security"
                "issuance"
            ),
        ]
    ] = None
    security_law_exemptions: Annotated[
        list[SecurityExemption],
        Field(
            description="List of security law exemptions (and applicable jurisdictions) for this security"
        ),
    ]
