"""Object describing equity compensation security release transaction"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-OCF/t
# ree/v1.1.0/schema/objects/transactions/release/EquityCompensationRelease.schema.
# json

from pydantic import Field
from pyocf.primitives.objects.object import Object
from pyocf.primitives.objects.transactions.release.release import Release
from pyocf.primitives.objects.transactions.securitytransaction import (
    SecurityTransaction,
)
from pyocf.primitives.objects.transactions.transaction import Transaction
from pyocf.types.date import Date
from pyocf.types.monetary import Monetary
from pyocf.types.numeric import Numeric
from typing import Annotated
from typing import Literal
from typing import Optional


class EquityCompensationRelease(Object, Transaction, SecurityTransaction, Release):
    """Object describing equity compensation security release transaction"""

    object_type: Annotated[
        Literal["TX_EQUITY_COMPENSATION_RELEASE"],
        Field(
            description="This is done to avoid a breaking change as we work towards a bigger restructure"
            "of the equity types in v2.0.0. `TX_PLAN_SECURITY_RELEASE` will be deprecated in"
            "v2.0.0"
        ),
    ] = "TX_EQUITY_COMPENSATION_RELEASE"
    id: Annotated[str, Field(description="Identifier for the object")]
    comments: Optional[
        Annotated[
            list[str],
            Field(
                description="Unstructured text comments related to and stored for the object"
            ),
        ]
    ] = None
    security_id: Annotated[
        str,
        Field(
            description="Identifier for the security (stock, plan security, warrant, or convertible) by"
            "which it can be referenced by other transaction objects. Note that while this"
            "identifier is created with an issuance object, it should be different than the"
            "issuance object's `id` field which identifies the issuance transaction object"
            "itself. All future transactions on the security (e.g. acceptance, transfer,"
            "cancel, etc.) must reference this `security_id` to qualify which security the"
            "transaction applies to."
        ),
    ]
    date: Annotated[Date, Field(description="Date on which the transaction occurred")]
    settlement_date: Annotated[
        Date,
        Field(
            description="The settlement date for the shares released, typically after the release"
            "transaction date"
        ),
    ]
    release_price: Annotated[
        Monetary,
        Field(
            description="The release price used to determine the value of the security at the time of"
            "release"
        ),
    ]
    quantity: Annotated[Numeric, Field(description="Quantity of shares released")]
    consideration_text: Optional[
        Annotated[
            str,
            Field(
                description="Unstructured text description of consideration provided in exchange for security"
                "release"
            ),
        ]
    ] = None
    resulting_security_ids: Annotated[
        list[str],
        Field(
            description="Identifier of the new security (or securities) issuance resulting from a release"
            "transaction"
        ),
    ]
