"""Object describing an acceleration of vesting, in which additional shares vest
ahead of the schedule specified in security\'s vesting terms."""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-OCF/t
# ree/v1.1.0/schema/objects/transactions/vesting/VestingAcceleration.schema.json

from pydantic import Field
from pyocf.primitives.objects.object import Object
from pyocf.primitives.objects.transactions.securitytransaction import (
    SecurityTransaction,
)
from pyocf.primitives.objects.transactions.transaction import Transaction
from pyocf.types.date import Date
from pyocf.types.numeric import Numeric
from typing import Annotated
from typing import Literal
from typing import Optional


class VestingAcceleration(Object, Transaction, SecurityTransaction):
    """Object describing an acceleration of vesting, in which additional shares vest
    ahead of the schedule specified in security\'s vesting terms.
    """

    object_type: Annotated[
        Literal["TX_VESTING_ACCELERATION"], Field(description="")
    ] = "TX_VESTING_ACCELERATION"
    quantity: Annotated[
        Numeric, Field(description="Number of shares vesting ahead of schedule")
    ]
    reason_text: Annotated[
        str, Field(description="Reason for the acceleration; unstructured text")
    ]
    id: Annotated[str, Field(description="Identifier for the object")]
    comments: Optional[
        Annotated[
            list[str],
            Field(
                description="Unstructured text comments related to and stored for the object"
            ),
        ]
    ] = None
    date: Annotated[Date, Field(description="Date on which the transaction occurred")]
    security_id: Annotated[
        str,
        Field(
            description="Identifier for the security (stock, plan security, warrant, or convertible) by"
            "which it can be referenced by other transaction objects. Note that while this"
            "identifier is created with an issuance object, it should be different than the"
            "issuance object's `id` field which identifies the issuance transaction object"
            "itself. All future transactions on the security (e.g. acceptance, transfer,"
            "cancel, etc.) must reference this `security_id` to qualify which security the"
            "transaction applies to."
        ),
    ]
