"""Object describing the transaction of an non-schedule-driven vesting event
associated with a security"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-
# OCF/tree/v1.1.0/schema/objects/transactions/vesting/VestingEvent.schema.json

from pydantic import Field
from pyocf.primitives.objects.object import Object
from pyocf.primitives.objects.transactions.securitytransaction import (
    SecurityTransaction,
)
from pyocf.primitives.objects.transactions.transaction import Transaction
from pyocf.types.date import Date
from typing import Annotated
from typing import Literal
from typing import Optional


class VestingEvent(Object, Transaction, SecurityTransaction):
    """Object describing the transaction of an non-schedule-driven vesting event
    associated with a security
    """

    object_type: Annotated[Literal["TX_VESTING_EVENT"], Field(description="")] = (
        "TX_VESTING_EVENT"
    )
    vesting_condition_id: Annotated[
        str,
        Field(
            description="Reference to the `id` of a VestingCondition in this security's VestingTerms."
            "This condition should have a trigger type of `VESTING_EVENT`."
        ),
    ]
    id: Annotated[str, Field(description="Identifier for the object")]
    comments: Optional[
        Annotated[
            list[str],
            Field(
                description="Unstructured text comments related to and stored for the object"
            ),
        ]
    ] = None
    date: Annotated[Date, Field(description="Date on which the transaction occurred")]
    security_id: Annotated[
        str,
        Field(
            description="Identifier for the security (stock, plan security, warrant, or convertible) by"
            "which it can be referenced by other transaction objects. Note that while this"
            "identifier is created with an issuance object, it should be different than the"
            "issuance object's `id` field which identifies the issuance transaction object"
            "itself. All future transactions on the security (e.g. acceptance, transfer,"
            "cancel, etc.) must reference this `security_id` to qualify which security the"
            "transaction applies to."
        ),
    ]
