"""Abstract object describing fields common to all issuance objects"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-OCF/t
# ree/v1.1.0/schema/primitives/objects/transactions/issuance/Issuance.schema.json

from pydantic import BaseModel
from pydantic import Field
from pyocf.types.date import Date
from pyocf.types.securityexemption import SecurityExemption
from typing import Annotated
from typing import Optional


class Issuance(BaseModel):
    """Abstract object describing fields common to all issuance objects"""

    custom_id: Annotated[
        str, Field(description="A custom ID for this security (e.g. CN-1.)")
    ]
    stakeholder_id: Annotated[
        str,
        Field(
            description="Identifier for the stakeholder that holds legal title to this security"
        ),
    ]
    board_approval_date: Optional[
        Annotated[Date, Field(description="Date of board approval for the security")]
    ] = None
    consideration_text: Optional[
        Annotated[
            str,
            Field(
                description="Unstructured text description of consideration provided in exchange for security"
                "issuance"
            ),
        ]
    ] = None
    security_law_exemptions: Annotated[
        list[SecurityExemption],
        Field(
            description="List of security law exemptions (and applicable jurisdictions) for this security"
        ),
    ]
