"""Abstract object describing fields common to all release transaction objects"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-OCF/t
# ree/v1.1.0/schema/primitives/objects/transactions/release/Release.schema.json

from pydantic import BaseModel
from pydantic import Field
from pyocf.types.date import Date
from pyocf.types.monetary import Monetary
from pyocf.types.numeric import Numeric
from typing import Annotated
from typing import Optional


class Release(BaseModel):
    """Abstract object describing fields common to all release transaction objects"""

    settlement_date: Annotated[
        Date,
        Field(
            description="The settlement date for the shares released, typically after the release"
            "transaction date"
        ),
    ]
    release_price: Annotated[
        Monetary,
        Field(
            description="The release price used to determine the value of the security at the time of"
            "release"
        ),
    ]
    quantity: Annotated[Numeric, Field(description="Quantity of shares released")]
    consideration_text: Optional[
        Annotated[
            str,
            Field(
                description="Unstructured text description of consideration provided in exchange for security"
                "release"
            ),
        ]
    ] = None
    resulting_security_ids: Annotated[
        list[str],
        Field(
            description="Identifier of the new security (or securities) issuance resulting from a release"
            "transaction"
        ),
    ]
