"""Type represents the rules for determining the capitalization definition for a
security"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-
# OCF/tree/v1.1.0/schema/types/CapitalizationDefinitionRules.schema.json

from pydantic import BaseModel
from pydantic import Field
from typing import Annotated


class CapitalizationDefinitionRules(BaseModel):
    """Type represents the rules for determining the capitalization definition for a
    security
    """

    include_outstanding_shares: Annotated[
        bool,
        Field(
            description="Include all outstanding share issuances in the capitalization definition"
        ),
    ]
    include_outstanding_options: Annotated[
        bool,
        Field(
            description="Include all outstanding options in the capitalization definition"
        ),
    ]
    include_outstanding_unissued_options: Annotated[
        bool,
        Field(
            description="Include all outstanding options that have been reserved but have not been issued"
            "yet in the capitalization definition"
        ),
    ]
    include_this_security: Annotated[
        bool,
        Field(
            description="Include the shares issued for converting this security in the capitalization"
            "definition"
        ),
    ]
    include_other_converting_securities: Annotated[
        bool,
        Field(
            description="Include the shares issued for converting all other convertibles that are"
            "converted as part of the conversion event in the capitalization definition"
        ),
    ]
    include_option_pool_topup_for_promised_options: Annotated[
        bool,
        Field(
            description="Include the shares reserved for increasing option plans to cover all promised"
            "options in the capitalization definition"
        ),
    ]
    include_additional_option_pool_topup: Annotated[
        bool,
        Field(
            description="Include the shares reserved for increasing option plans beyond the amount needed"
            "for any promised options in the capitalization definition"
        ),
    ]
    include_new_money: Annotated[
        bool,
        Field(
            description="Include the shares issued for any new share subscriptions that are part of the"
            "conversion event in the capitalization definition"
        ),
    ]
