"""Sets forth inputs and conversion mechanism of a convertible note"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-OCF/t
# ree/v1.1.0/schema/types/conversion_mechanisms/NoteConversionMechanism.schema.jso
# n

from pydantic import Field
from pyocf.enums.accrualperiodtype import AccrualPeriodType
from pyocf.enums.compoundingtype import CompoundingType
from pyocf.enums.daycounttype import DayCountType
from pyocf.enums.interestpayouttype import InterestPayoutType
from pyocf.primitives.types.conversion_mechanisms.conversionmechanism import (
    ConversionMechanism,
)
from pyocf.types.capitalizationdefinitionrules import CapitalizationDefinitionRules
from pyocf.types.interestrate import InterestRate
from pyocf.types.monetary import Monetary
from pyocf.types.percentage import Percentage
from pyocf.types.ratio import Ratio
from typing import Annotated
from typing import Literal
from typing import Optional


class NoteConversionMechanism(ConversionMechanism):
    """Sets forth inputs and conversion mechanism of a convertible note"""

    type: Annotated[Literal["CONVERTIBLE_NOTE_CONVERSION"], Field(description="")] = (
        "CONVERTIBLE_NOTE_CONVERSION"
    )
    interest_rates: Annotated[
        list[InterestRate],
        Field(description="Interest rate(s) of the convertible (if applicable)"),
    ]
    day_count_convention: Annotated[
        DayCountType,
        Field(
            description="How many days are there is a given period for calculation purposes?"
        ),
    ]
    interest_payout: Annotated[
        InterestPayoutType,
        Field(description="How is interest paid out (if at applicable)"),
    ]
    interest_accrual_period: Annotated[
        AccrualPeriodType,
        Field(description="What is the period over which interest is calculated?"),
    ]
    compounding_type: Annotated[
        CompoundingType, Field(description="What type of interest compounding?")
    ]
    conversion_discount: Optional[
        Annotated[
            Percentage,
            Field(
                description="What is the percentage discount available upon conversion, if applicable?"
                "(decimal representation - e.g. 0.125 for 12.5%)"
            ),
        ]
    ] = None
    conversion_valuation_cap: Optional[
        Annotated[
            Monetary, Field(description="What is the valuation cap (if applicable)?")
        ]
    ] = None
    capitalization_definition: Optional[
        Annotated[
            str,
            Field(
                description="How is company capitalization defined for purposes of conversion? If possible,"
                "include the legal language from the instrument."
            ),
        ]
    ] = None
    capitalization_definition_rules: Optional[
        Annotated[
            CapitalizationDefinitionRules,
            Field(
                description="The rules for which types of securities would be included in the capitalization"
                "definition."
            ),
        ]
    ] = None
    exit_multiple: Optional[
        Annotated[
            Ratio,
            Field(
                description="For cash proceeds calculation during a liquidity event."
            ),
        ]
    ] = None
    conversion_mfn: Optional[
        Annotated[
            bool,
            Field(
                description="Is this an MFN (Most Favored Nations) flavored Convertible Note?"
            ),
        ]
    ] = None
