"""Type representation of elective trigger valid on or after start_date and until
or before end_date."""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-OCF/t
# ree/v1.1.0/schema/types/conversion_triggers/ElectiveConversionInDateRangeTrigger
# .schema.json

from pydantic import Field
from pyocf.primitives.types.conversion_triggers.conversiontrigger import (
    ConversionTrigger,
)
from pyocf.types.conversion_rights.convertibleconversionright import (
    ConvertibleConversionRight,
)
from pyocf.types.conversion_rights.stockclassconversionright import (
    StockClassConversionRight,
)
from pyocf.types.conversion_rights.warrantconversionright import WarrantConversionRight
from pyocf.types.date import Date
from typing import Annotated
from typing import Literal
from typing import Optional
from typing import Union


class ElectiveConversionInDateRangeTrigger(ConversionTrigger):
    """Type representation of elective trigger valid on or after start_date and until
    or before end_date.
    """

    trigger_id: Annotated[
        str,
        Field(
            description="Id for this conversion trigger, unique within list of ConversionTriggers in"
            "parent convertible issuance's `conversion_triggers` field."
        ),
    ]
    type: Annotated[Literal["ELECTIVE_IN_RANGE"], Field(description="")] = (
        "ELECTIVE_IN_RANGE"
    )
    start_date: Annotated[Date, Field(description="Start date of range (inclusive)")]
    end_date: Annotated[Date, Field(description="End date of range (inclusive)")]
    nickname: Optional[
        Annotated[
            str,
            Field(
                description="Human-friendly nickname to describe the conversion right"
            ),
        ]
    ] = None
    trigger_description: Optional[
        Annotated[str, Field(description="Long-form description of the trigger")]
    ] = None
    conversion_right: Annotated[
        Union[
            ConvertibleConversionRight,
            WarrantConversionRight,
            StockClassConversionRight,
        ],
        Field(
            discriminator="type",
            description="When the conditions of the trigger are met, how does the convertible convert?",
        ),
    ]
