"""Type representation of a range of share numbers associated with an event (such
as the share numbers associated with an issuance) - for use where shares are not
fungible and need unique identifiers *per share*"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-
# OCF/tree/v1.1.0/schema/types/ShareNumberRange.schema.json

from pydantic import BaseModel
from pydantic import Field
from pyocf.types.numeric import Numeric
from typing import Annotated


class ShareNumberRange(BaseModel):
    """Type representation of a range of share numbers associated with an event (such
    as the share numbers associated with an issuance) - for use where shares are not
    fungible and need unique identifiers *per share*
    """

    starting_share_number: Annotated[
        Numeric,
        Field(
            description="The starting share number of a range of shares impacted by a particular event"
            "(**INCLUSIVE** and assuming **share counts start at 1**)"
        ),
    ]
    ending_share_number: Annotated[
        Numeric,
        Field(
            description="The ending share number of a range of shares impacted by a particular event"
            "(**INCLUSIVE**)"
        ),
    ]
