"""Type representation of the parent security of a given stock issuance (e.g. if a
stock issuance came from a plan, such as an RSA, or if a stock came from a
previous stock entry)"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2023 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-
# OCF/tree/v1.1.0/schema/types/StockParent.schema.json

from pydantic import BaseModel
from pydantic import Field
from pyocf.enums.parentsecuritytype import ParentSecurityType
from typing import Annotated


class StockParent(BaseModel):
    """Type representation of the parent security of a given stock issuance (e.g. if a
    stock issuance came from a plan, such as an RSA, or if a stock came from a
    previous stock entry)
    """

    parent_object_type: Annotated[
        ParentSecurityType,
        Field(
            description="Parent object type for this stock issuance (e.g. a stock plan or warrant)"
        ),
    ]
    parent_object_id: Annotated[
        str,
        Field(
            description="Parent object's ID must be a valid ID pointing to an object of the type"
            "specified in parent_object_type"
        ),
    ]
